%% Matrix definitions
dist = @(x) [1 x(1); 0 1];                           % distance
mirror = @(R) [1 0; -2/R(1) 1];                      % radius
dielectric = @(n1,n2,R) [1 0; (n1-n2)/(R*n2) n1/n2]; % n1, n2, R for an interface
lens = @(r1, r2, th) dielectric(1.45, 1, r2)*dist(th)*dielectric(1, 1.45, r1);
       % r1, r2, thickness.  R1 > 0 for convex,  R1 < 0 for concave.  
       % R2 vice versa.  Assumed fused silica, hence n = 1.45

       
% Matrix transformation
qNew = @(q,ABCD) (q*ABCD(1,1)+ABCD(1,2)) / (q*ABCD(2,1)+ABCD(2,2));


%% The input beam
[z0,z1,z2] = cavHG(3995, 1970, 2190);                 % The waist is defined by the arm cavity
q_arm = waist2q(sqrt(z0*1.064e-6/pi), 0);    
toTelescope = lens(-2070, inf, 0.204) * dist(z2);

q_input = qNew(q_arm, toTelescope)


%% The astigmatic telescope
L = 1.9362;
R1 = 4.00;
R2 = -0.133;
lambda = 1.064e-6;

telescope = @(theta) mirror(R2*(1+theta^2/2)) * dist(L) * mirror(R1);
q_out = @(theta) qNew(q_input, telescope(theta));
deviate= @(theta) -2*real(q_out(theta))/ (pi*q2waist(1i*imag(q_out(theta)))^2/lambda) ;

AOI = [0:0.1:5]/180*pi;
for ii = 1:length(AOI)
    astig(ii) = deviate(AOI(ii));
end

%% plot figure
figure(1)
clf;
set(gca, 'Fontsize', 16);
plot(AOI*180/pi, astig)
ylabel('\delta Z / Z_R');
xlabel('Secondary AOI [deg]');
title('Effect of telescope astigmatism');
grid;