%% Matrix definitions
dist = @(x) [1 x(1); 0 1];                           % distance
mirror = @(R) [1 0; -2/R(1) 1];                      % radius
dielectric = @(n1,n2,R) [1 0; (n1-n2)/(R*n2) n1/n2]; % n1, n2, R for an interface
N_index = 1.4607;
lens = @(r1, r2, th, n) dielectric(n, 1, r2)*dist(th)*dielectric(1, n, r1);
       % r1, r2, thickness.  R1 > 0 for convex,  R1 < 0 for concave.  
       % R2 vice versa.  Assumed fused silica, hence n = 1.45

       
% Matrix transformation
qNew = @(q,ABCD) (q*ABCD(1,1)+ABCD(1,2)) / (q*ABCD(2,1)+ABCD(2,2));


%% The input beam
[z0,z1,z2] = cavHG(3995, 1970, 2190);                 % The waist is defined by the arm cavity
q_arm = waist2q(sqrt(z0*1.064e-6/pi), 0);    
toTelescope = lens(-2070, inf, 0.204, 1.45) * dist(z2);

q_input = qNew(q_arm, toTelescope);


%% The astigmatic telescope
L = 2.125;
R1 = 4.00;
R2 = 0.250;   % for this calculation we treat the achromat as a mirror
lambda = 1.064e-6;

telescope = @(L) mirror(R2) * dist(L) * mirror(R1);
q_out = @(L) qNew(q_input, telescope(L));



LL = [2.125:1e-5:2.13];
clear focus waistiness ZR;
for ii = 1:length(LL)
    focus(ii) = real(q_out(LL(ii)));
    waistiness(ii) = q2waist(i*imag(q_out(LL(ii))));
end
ZR = pi * waistiness.^2/lambda;


%% plot figure
figure(1)
clf;
subplot(2,1,1)
set(gca, 'Fontsize', 16);
plot(LL, focus./ZR)
ylabel('\delta Z / Z_{R} ');

%title('Output waist detuning');
grid;

subplot(2,1,2)
set(gca, 'Fontsize', 16);
plot(LL, waistiness*1000)
ylabel('waist size [mm]');
xlabel('Secondary distance [m]');
grid;

shg